OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "All contacts" : "Todos los contactos",
    "Details" : "Detalles",
    "A contacts app for Nextcloud" : "Una aplicación de contactos para Nextcloud",
    "Copy to full name" : "Copiar a nombre completo",
    "Omit year" : "Omitir año",
    "Add new property" : "Añadir nueva propiedad",
    "Choose property type" : "Elija el tipo de propiedad",
    "Add a new picture" : "Agregar una nueva foto",
    "Upload a new picture" : "Subir una nueva imagen",
    "Choose from files" : "Elige entre archivos",
    "Download picture" : "Descargar imágen",
    "Image is too big (max 1MB)." : "La imagen es demasiado grande (máximo 1MB).",
    "No contact selected" : "Contacto no seleccionado",
    "Select a contact on the list to begin" : "Seleccione un contacto en la lista para comenzar",
    "Loading" : "Cargando",
    "Name" : "Nombre",
    "Company" : "Empresa",
    "Title" : "Título",
    "Download" : "Descargar",
    "Generate QR Code" : "Generar código QR",
    "Delete" : "Borrar",
    "This contact is not yet synced. Edit it to save it to the server." : "Este contacto aún no está sincronizado. Edítalo para guardarlo en el servidor.",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está en modo de sólo lectura. No tienes permiso para editar este contacto.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacto que intentabas editar ha cambiado. Por favor actualice manualmente el contacto. Cualquier otra edición será descartada.",
    "Addressbook" : "Directorio",
    "Groups" : "Grupos",
    "New contact" : "Nuevo contacto",
    "Importing {total} contacts into" : "Importando {total} contactos a",
    "No errors" : "Sin errores",
    "Open your browser console for more details" : "Abra la consola de su navegador para más detalles",
    "Select type" : "Seleccionar tipo",
    "Select Date" : "Seleccionar fecha",
    "Add contact in group" : "Añadir contacto en grupo",
    "No results" : "Sin resultados",
    "Last modified" : "Última modificación",
    "Select option" : "Seleccionar opción",
    "Rename" : "Renombrar",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado",
    "Copied" : "Copiado",
    "Can not copy" : "No se puede copiar",
    "Copy link" : "Copiar enlace",
    "Enabled toggle of addressbook was not successful." : "La alternancia habilitada de la libreta de direcciones no tuvo éxito.",
    "This will delete the addressbook and every contacts within it" : "Esto eliminará la libreta de direcciones y todos los contactos dentro de ella.",
    "Delete {addressbook} ?" : "¿Borrar {addressbook} ?",
    "Deletion of addressbook was not successful." : "La eliminación de la libreta de direcciones no tuvo éxito.",
    "Renaming of addressbook was not successful." : "El cambio de nombre de la libreta de direcciones no tuvo éxito.",
    "Addressbook copied to clipboard" : "Libreta de direcciones copiada al portapapeles",
    "Addressbook was not copied to clipboard." : "La libreta de direcciones no se copió al portapapeles.",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "can edit" : "poder editar",
    "Unable to delete the share." : "No se puede eliminar el recurso compartido.",
    "Unable to change permissions." : "No se pueden cambiar los permisos.",
    "Importing into" : "Importando en",
    "Import into" : "Importar en",
    "Importing is disabled because there are no address books available" : "La importación está deshabilitada porque no hay libretas de direcciones disponibles",
    "Address book name" : "Nombre de la libreta de direcciones",
    "An error occurred, unable to create the addressbook." : "Se produjo un error, no se puede crear la libreta de direcciones.",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Display name" : "Nombre para mostrar",
    "Sort by {sorting}" : "Ordenar por {sorting}",
    "Not grouped" : "No agrupado",
    "Unable to create the contact." : "No se puede crear el contacto.",
    "Contact not found" : "Contacto no encontrado",
    "Nickname" : "Apodo",
    "Detailed name" : "Nombre detallado",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "Id de nube federada",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado postal",
    "Extended address" : "Dirección extendida",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de defunción",
    "Email" : "Correo electrónico",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono fijo",
    "Mobile" : "Teléfono móvil",
    "Work mobile" : "Trabajo movil",
    "Home mobile" : "Casa móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Coche",
    "Work pager" : "Buscapersonas de trabajo",
    "Social network" : "Red social",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "La url del perfil. Por ejemplo: https://www.facebook.com/Nextclouders/",
    "Relationship" : "Relación",
    "Specify a relationship between you and the entity represented by this vCard." : "Especifique una relación entre usted y la entidad representada por esta vCard.",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Padre",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Relativo",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Manager" : "Gerente",
    "Assistant" : "Asistente",
    "Related" : "Relacionado",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Especifique una relación entre otra entidad y la entidad representada por esta vCard.",
    "Contact" : "Contacto",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Co-trabajador",
    "Gender" : "Género",
    "Female" : "Femenino",
    "Male" : "Masculino",
    "None" : "Ninguno",
    "Unknown" : "Desconocido",
    "Timezone" : "Zona horaria",
    "An error occurred" : "Ocurrió un error"
},
"nplurals=2; plural=(n != 1);");
